@@ -30,10 +30,9 @@
 #include <QOpenGLFunctions>
 #include <QOpenGLBuffer>
 #include <QOpenGLShaderProgram>
+#include "analitzaplotexport.h"
 
 class QAbstractItemModel;
-class QPainter;
-class QPaintDevice;
 class QModelIndex;
 
 namespace Analitza
@@ -59,7 +58,7 @@ class ANALITZAPLOT_EXPORT Plotter3DES : private QOpenGLFunctions
         //TODO transparency effect when select current item
 //         enum FocusEffect {};
 
-        Plotter3DES(QAbstractItemModel* model = 0);
+        explicit Plotter3DES(QAbstractItemModel* model = nullptr);
         virtual ~Plotter3DES();
 
         virtual void initGL();
@@ -109,7 +108,7 @@ class ANALITZAPLOT_EXPORT Plotter3DES : private QOpenGLFunctions
         void hideAxisHint();
 
         /**  If the flag @p simplerot is true the rotation ignores any fixed or free direction */
-        void setUseSimpleRotation(bool simplerot);
+        ANALITZAPLOT_DEPRECATED void setUseSimpleRotation(bool simplerot);
 
         /**  Get information about the current rotarion approach: if return true then rotation is simple. */
         bool isUsingSimpleRotation() const { return m_simpleRotation; }
@@ -131,6 +130,8 @@ class ANALITZAPLOT_EXPORT Plotter3DES : private QOpenGLFunctions
          */
         QStringList filters() const;
 
+        void setReferencePlaneColor(const QColor &color) { m_referencePlaneColor = color; }
+
     protected:
         void addPlots(PlotItem* item);
 
